# Microservice for scheduling tasks


Set path to SQLite database file via variable `WORKPLANNER_DATABASE_PATH`



## Install
    poetry add workplanner

or

    pip install workplanner


## Run
    workplanner run --help
    workplanner run

Default port 14444

[Swagger](https://github.com/swagger-api/swagger-ui): \
http://127.0.0.1:14444/docs

[Redoc](https://github.com/Redocly/redoc): \
http://127.0.0.1:14444/redoc
